==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/pt-PT/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Confirmar Apagar artigos seleccionados',
  'bulk_delete_help'	=> 'Reveja os ativos para apagar abaixo. Depois de apagados, estes ativos podem ser restaurados, mas não estarão associados aos utilizadores.',
  'bulk_delete_warn'	=> 'Vai apagar :asset_count ativos.',
	'bulk_update'		=> 'Atualização de ativos em massa',
	'bulk_update_help'	=> 'Este formulário permite a atualização em massa de ativos. Preencha apenas os atributos que precisam de alteração. Qualquer atributo deixado em branco permanecerá inalterado. ',
	'bulk_update_warn'	=> 'Está prestes a editar as propriedades :asset_count dos ativos.',
    'checkedout_to'		=> 'Alocado a',
    'checkout_date'		=> 'Data de alocação',
    'checkin_date'		=> 'Data de devolução',
    'checkout_to'		=> 'Alocar a',
    'cost'				=> 'Custo de aquisição',
    'create'			=> 'Criar Ativo',
    'date'				=> 'Data de aquisição',
    'depreciation'	    => 'Depreciação',
    'depreciates_on'	=> 'Deprecia em',
    'default_location'	=> 'Localização padrão',
    'eol_date'			=> 'Data de EOL',
    'eol_rate'			=> 'Taxa de EOL',
    'expected_checkin'  => 'Data de devolução esperada',
    'expires'			=> 'Expira a',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Se pretende alocar este ativo imediatamente, selecione "Pronto para implementar" na lista de Estados acima. ',
    'mac_address'		=> 'Endereço MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nome do Ativo',
    'notes'				=> 'Notas',
    'order'				=> 'Nº de encomenda',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Utilizadores podem solicitar este ativo',
    'select_statustype'	=> 'Selecionar Estado',
    'serial'			=> 'Nº de Série',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta do Ativo',
    'update'			=> 'Atualização do ativo',
    'warranty'			=> 'Garantia',
		'warranty_expires'		=> 'Garantia expira',
    'years'				=> 'anos',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/pt-PT/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirmar Apagar artigos seleccionados',
  'bulk_delete_help'	=> 'Reveja os ativos para apagar abaixo. Depois de apagados, estes ativos podem ser restaurados, mas não estarão associados aos utilizadores.',
  'bulk_delete_warn'	=> 'Vai apagar :asset_count ativos.',
    'bulk_update'		=> 'Atualização de ativos em massa',
    'bulk_update_help'	=> 'Este formulário permite a atualização em massa de ativos. Preencha apenas os atributos que precisam de alteração. Qualquer atributo deixado em branco permanecerá inalterado. ',
    'bulk_update_warn'	=> 'Está prestes a editar as propriedades :asset_count dos ativos.',
    'checkedout_to'		=> 'Alocado a',
    'checkout_date'		=> 'Data de alocação',
    'checkin_date'		=> 'Data de devolução',
    'checkout_to'		=> 'Alocar a',
    'cost'				=> 'Custo de aquisição',
    'create'			=> 'Criar Ativo',
    'date'				=> 'Data de aquisição',
    'depreciation'	    => 'Depreciação',
    'depreciates_on'	=> 'Deprecia em',
    'default_location'	=> 'Localização padrão',
    'eol_date'			=> 'Data de EOL',
    'eol_rate'			=> 'Taxa de EOL',
    'expected_checkin'  => 'Data de devolução esperada',
    'expires'			=> 'Expira a',
    'fully_depreciated'	=> 'Totalmente Depreciado',
    'help_checkout'		=> 'Se pretende alocar este ativo imediatamente, selecione "Pronto para implementar" na lista de Estados acima. ',
    'mac_address'		=> 'Endereço MAC',
    'manufacturer'		=> 'Fabricante',
    'model'				=> 'Modelo',
    'months'			=> 'meses',
    'name'				=> 'Nome do Ativo',
    'notes'				=> 'Notas',
    'order'				=> 'Nº de encomenda',
    'qr'				=> 'Código QR',
    'requestable'		=> 'Utilizadores podem solicitar este ativo',
    'select_statustype'	=> 'Selecionar Estado',
    'serial'			=> 'Nº de Série',
    'status'			=> 'Estado',
    'tag'				=> 'Etiqueta do Ativo',
    'update'			=> 'Atualização do ativo',
    'warranty'			=> 'Garantia',
        'warranty_expires'		=> 'Garantia expira',
    'years'				=> 'anos',
    'asset_location' => 'Atualizar a localização do artigo',
    'asset_location_update_default_current' => 'Atualizar a localização por defeito E localização atual',
    'asset_location_update_default' => 'Atualizar apenas a localização por defeito',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'A processar...',
];
